import { localize } from '../../nls.js';

const minute = 60;
const hour = minute * 60;
const day = hour * 24;
const week = day * 7;
const month = day * 30;
const year = day * 365;
function fromNow(date, appendAgoLabel, useFullTimeWords, disallowNow) {
    if (typeof date !== 'number') {
        date = date.getTime();
    }
    const seconds = Math.round((( (new Date())).getTime() - date) / 1000);
    if (seconds < -30) {
        return ( localize(
            1331,
            'in {0}',
            fromNow(( (new Date())).getTime() + seconds * 1000, false)
        ));
    }
    if (!disallowNow && seconds < 30) {
        return ( localize(1332, 'now'));
    }
    let value;
    if (seconds < minute) {
        value = seconds;
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1333, '{0} second ago', value))
                    : ( localize(1334, '{0} sec ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1335, '{0} seconds ago', value))
                    : ( localize(1336, '{0} secs ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1337, '{0} second', value))
                    : ( localize(1338, '{0} sec', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1339, '{0} seconds', value))
                    : ( localize(1340, '{0} secs', value));
            }
        }
    }
    if (seconds < hour) {
        value = Math.floor(seconds / minute);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1341, '{0} minute ago', value))
                    : ( localize(1342, '{0} min ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1343, '{0} minutes ago', value))
                    : ( localize(1344, '{0} mins ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1345, '{0} minute', value))
                    : ( localize(1346, '{0} min', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1347, '{0} minutes', value))
                    : ( localize(1348, '{0} mins', value));
            }
        }
    }
    if (seconds < day) {
        value = Math.floor(seconds / hour);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1349, '{0} hour ago', value))
                    : ( localize(1350, '{0} hr ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1351, '{0} hours ago', value))
                    : ( localize(1352, '{0} hrs ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1353, '{0} hour', value))
                    : ( localize(1354, '{0} hr', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1355, '{0} hours', value))
                    : ( localize(1356, '{0} hrs', value));
            }
        }
    }
    if (seconds < week) {
        value = Math.floor(seconds / day);
        if (appendAgoLabel) {
            return value === 1
                ? ( localize(1357, '{0} day ago', value))
                : ( localize(1358, '{0} days ago', value));
        }
        else {
            return value === 1
                ? ( localize(1359, '{0} day', value))
                : ( localize(1360, '{0} days', value));
        }
    }
    if (seconds < month) {
        value = Math.floor(seconds / week);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1361, '{0} week ago', value))
                    : ( localize(1362, '{0} wk ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1363, '{0} weeks ago', value))
                    : ( localize(1364, '{0} wks ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1365, '{0} week', value))
                    : ( localize(1366, '{0} wk', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1367, '{0} weeks', value))
                    : ( localize(1368, '{0} wks', value));
            }
        }
    }
    if (seconds < year) {
        value = Math.floor(seconds / month);
        if (appendAgoLabel) {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1369, '{0} month ago', value))
                    : ( localize(1370, '{0} mo ago', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1371, '{0} months ago', value))
                    : ( localize(1372, '{0} mos ago', value));
            }
        }
        else {
            if (value === 1) {
                return useFullTimeWords
                    ? ( localize(1373, '{0} month', value))
                    : ( localize(1374, '{0} mo', value));
            }
            else {
                return useFullTimeWords
                    ? ( localize(1375, '{0} months', value))
                    : ( localize(1376, '{0} mos', value));
            }
        }
    }
    value = Math.floor(seconds / year);
    if (appendAgoLabel) {
        if (value === 1) {
            return useFullTimeWords
                ? ( localize(1377, '{0} year ago', value))
                : ( localize(1378, '{0} yr ago', value));
        }
        else {
            return useFullTimeWords
                ? ( localize(1379, '{0} years ago', value))
                : ( localize(1380, '{0} yrs ago', value));
        }
    }
    else {
        if (value === 1) {
            return useFullTimeWords
                ? ( localize(1381, '{0} year', value))
                : ( localize(1382, '{0} yr', value));
        }
        else {
            return useFullTimeWords
                ? ( localize(1383, '{0} years', value))
                : ( localize(1384, '{0} yrs', value));
        }
    }
}
function fromNowByDay(date, appendAgoLabel, useFullTimeWords) {
    if (typeof date !== 'number') {
        date = date.getTime();
    }
    const todayMidnightTime = ( (new Date()));
    todayMidnightTime.setHours(0, 0, 0, 0);
    const yesterdayMidnightTime = ( (new Date(todayMidnightTime.getTime())));
    yesterdayMidnightTime.setDate(yesterdayMidnightTime.getDate() - 1);
    if (date > todayMidnightTime.getTime()) {
        return ( localize(1385, 'Today'));
    }
    if (date > yesterdayMidnightTime.getTime()) {
        return ( localize(1386, 'Yesterday'));
    }
    return fromNow(date, appendAgoLabel, useFullTimeWords);
}
function getDurationString(ms, useFullTimeWords) {
    const seconds = Math.abs(ms / 1000);
    if (seconds < 1) {
        return ( localize(1388, '{0}ms', ms));
    }
    if (seconds < minute) {
        return ( localize(1390, '{0}s', Math.round(ms) / 1000));
    }
    if (seconds < hour) {
        return ( localize(1392, '{0} mins', Math.round(ms / (1000 * minute))));
    }
    if (seconds < day) {
        return ( localize(1394, '{0} hrs', Math.round(ms / (1000 * hour))));
    }
    return ( localize(1395, '{0} days', Math.round(ms / (1000 * day))));
}
function toLocalISOString(date) {
    return date.getFullYear() +
        '-' + String(date.getMonth() + 1).padStart(2, '0') +
        '-' + String(date.getDate()).padStart(2, '0') +
        'T' + String(date.getHours()).padStart(2, '0') +
        ':' + String(date.getMinutes()).padStart(2, '0') +
        ':' + String(date.getSeconds()).padStart(2, '0') +
        '.' + (date.getMilliseconds() / 1000).toFixed(3).slice(2, 5) +
        'Z';
}

export { fromNow, fromNowByDay, getDurationString, toLocalISOString };
